==> gist-publish-npm-1.2.4.tgz: package/lib/package.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var jsonOrThrowError = function () {
	var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(response) {
		var json;
		return _regenerator2.default.wrap(function _callee$(_context) {
			while (1) {
				switch (_context.prev = _context.next) {
					case 0:
						_context.next = 2;
						return response.json();

					case 2:
						json = _context.sent;

						if (!response.ok) {
							_context.next = 7;
							break;
						}

						return _context.abrupt('return', json);

					case 7:
						throw new Error(json.message || r.statusText);

					case 8:
					case 'end':
						return _context.stop();
				}
			}
		}, _callee, this);
	}));
	return function jsonOrThrowError(_x) {
		return ref.apply(this, arguments);
	};
}();

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _detective = require('detective');

var _detective2 = _interopRequireDefault(_detective);

var _nodeFetch = require('node-fetch');

var _nodeFetch2 = _interopRequireDefault(_nodeFetch);

var _builtinModules = require('builtin-modules');

var _builtinModules2 = _interopRequireDefault(_builtinModules);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = (0, _bluebird.promisifyAll)(_fs2.default);

var infer = {
	main: function main(id, dir, repo) {
		var _this = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
			var files, jsfiles;
			return _regenerator2.default.wrap(function _callee2$(_context2) {
				while (1) {
					switch (_context2.prev = _context2.next) {
						case 0:
							_context2.next = 2;
							return fs.readdirAsync(dir);

						case 2:
							files = _context2.sent;
							jsfiles = files.filter(function (file) {
								return file.endsWith('.js');
							});
							return _context2.abrupt('return', jsfiles[0]);

						case 5:
						case 'end':
							return _context2.stop();
					}
				}
			}, _callee2, _this);
		}))();
	},
	version: function version(id, dir, repo) {
		var _this2 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
			var master, commits;
			return _regenerator2.default.wrap(function _callee3$(_context3) {
				while (1) {
					switch (_context3.prev = _context3.next) {
						case 0:
							_context3.next = 2;
							return repo.getBranchCommit('master');

						case 2:
							master = _context3.sent;
							_context3.next = 5;
							return new _bluebird2.default(function (resolve, reject) {
								var history = master.history();
								history.on('end', resolve);
								history.on('error', reject);
								history.start();
							});

						case 5:
							commits = _context3.sent;
							return _context3.abrupt('return', '1.' + (commits.length - 1) + '.0');

						case 7:
						case 'end':
							return _context3.stop();
					}
				}
			}, _callee3, _this2);
		}))();
	},
	name: function name(id, dir, repo) {
		var _this3 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee4() {
			var main, name, gist;
			return _regenerator2.default.wrap(function _callee4$(_context4) {
				while (1) {
					switch (_context4.prev = _context4.next) {
						case 0:
							_context4.next = 2;
							return infer.main(id, dir, repo);

						case 2:
							main = _context4.sent;
							name = _path2.default.basename(main, '.js');
							_context4.next = 6;
							return (0, _nodeFetch2.default)('https://api.github.com/gists/' + id).then(jsonOrThrowError);

						case 6:
							gist = _context4.sent;
							return _context4.abrupt('return', '@' + gist.owner.login + '/' + name);

						case 8:
						case 'end':
							return _context4.stop();
					}
				}
			}, _callee4, _this3);
		}))();
	},
	author: function author(id, dir, repo) {
		var _this4 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee5() {
			var commit, author;
			return _regenerator2.default.wrap(function _callee5$(_context5) {
				while (1) {
					switch (_context5.prev = _context5.next) {
						case 0:
							_context5.next = 2;
							return repo.getBranchCommit('master');

						case 2:
							commit = _context5.sent;
							_context5.next = 5;
							return commit.author();

						case 5:
							author = _context5.sent;
							return _context5.abrupt('return', author.name() + ' <' + author.email() + '>');

						case 7:
						case 'end':
							return _context5.stop();
					}
				}
			}, _callee5, _this4);
		}))();
	},
	dependencies: function dependencies(id, dir, repo) {
		var _this5 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee6() {
			var mainPath, src, packages;
			return _regenerator2.default.wrap(function _callee6$(_context6) {
				while (1) {
					switch (_context6.prev = _context6.next) {
						case 0:
							_context6.t0 = _path2.default;
							_context6.t1 = dir;
							_context6.next = 4;
							return infer.main(id, dir, repo);

						case 4:
							_context6.t2 = _context6.sent;
							mainPath = _context6.t0.resolve.call(_context6.t0, _context6.t1, _context6.t2);
							_context6.next = 8;
							return fs.readFileAsync(mainPath, 'utf8');

						case 8:
							src = _context6.sent;
							packages = (0, _detective2.default)(src);
							return _context6.abrupt('return', stars(packages.filter(function (p) {
								return p.indexOf('.') !== 0 && _builtinModules2.default.indexOf(p) === -1;
							}).map(actualPackageName)));

						case 11:
						case 'end':
							return _context6.stop();
					}
				}
			}, _callee6, _this5);
		}))();
	}
};

var actualPackageName = function actualPackageName(req) {
	return req.split('/', req[0] === '@' ? 2 : 1).join('/');
};
var stars = function stars(deps) {
	return arraysToObj(deps, arrayN(deps.length, '*'));
}; //yolo
var arrayN = function arrayN(n, x) {
	return n <= 0 ? [] : [x].concat(arrayN(n - 1, x));
};
var arraysToObj = function arraysToObj(xs, ys) {
	return xs.reduce(function (o, x, i) {
		return o[x] = ys[i], o;
	}, {});
};

module.exports = function () {
	var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee7(id, dir, repo) {
		var keys, values;
		return _regenerator2.default.wrap(function _callee7$(_context7) {
			while (1) {
				switch (_context7.prev = _context7.next) {
					case 0:
						keys = (0, _keys2.default)(infer);
						_context7.next = 3;
						return _bluebird2.default.all(keys.map(function (k) {
							return infer[k](id, dir, repo);
						}));

					case 3:
						values = _context7.sent;
						return _context7.abrupt('return', arraysToObj(keys, values));

					case 5:
					case 'end':
						return _context7.stop();
				}
			}
		}, _callee7, this);
	}));
	return function (_x2, _x3, _x4) {
		return ref.apply(this, arguments);
	};
}();

==> gist-publish-npm-1.4.0-0.tgz: package/lib/package.js <==
'use strict';

var _keys = require('babel-runtime/core-js/object/keys');

var _keys2 = _interopRequireDefault(_keys);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var jsonOrThrowError = function () {
	var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(response) {
		var json;
		return _regenerator2.default.wrap(function _callee$(_context) {
			while (1) {
				switch (_context.prev = _context.next) {
					case 0:
						_context.next = 2;
						return response.json();

					case 2:
						json = _context.sent;

						if (!response.ok) {
							_context.next = 7;
							break;
						}

						return _context.abrupt('return', json);

					case 7:
						throw new Error(json.message || r.statusText);

					case 8:
					case 'end':
						return _context.stop();
				}
			}
		}, _callee, this);
	}));
	return function jsonOrThrowError(_x) {
		return ref.apply(this, arguments);
	};
}();

var getExtraMetadata = function () {
	var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee9(id) {
		var _ref, description;

		return _regenerator2.default.wrap(function _callee9$(_context9) {
			while (1) {
				switch (_context9.prev = _context9.next) {
					case 0:
						_context9.next = 2;
						return getGist(id);

					case 2:
						_ref = _context9.sent;
						description = _ref.description;
						return _context9.abrupt('return', _ljson2.default.parse(description));

					case 5:
					case 'end':
						return _context9.stop();
				}
			}
		}, _callee9, this);
	}));
	return function getExtraMetadata(_x2) {
		return ref.apply(this, arguments);
	};
}();

var _bluebird = require('bluebird');

var _bluebird2 = _interopRequireDefault(_bluebird);

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _detective = require('detective');

var _detective2 = _interopRequireDefault(_detective);

var _nodeFetch = require('node-fetch');

var _nodeFetch2 = _interopRequireDefault(_nodeFetch);

var _builtinModules = require('builtin-modules');

var _builtinModules2 = _interopRequireDefault(_builtinModules);

var _ljson = require('ljson');

var _ljson2 = _interopRequireDefault(_ljson);

var _lodash = require('lodash.merge');

var _lodash2 = _interopRequireDefault(_lodash);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var fs = (0, _bluebird.promisifyAll)(_fs2.default);

var getGist = function getGist(id) {
	return (0, _nodeFetch2.default)('https://api.github.com/gists/' + id).then(jsonOrThrowError);
};

var infer = {
	main: function main(id, dir, repo) {
		var _this = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2() {
			var files, jsfiles;
			return _regenerator2.default.wrap(function _callee2$(_context2) {
				while (1) {
					switch (_context2.prev = _context2.next) {
						case 0:
							_context2.next = 2;
							return fs.readdirAsync(dir);

						case 2:
							files = _context2.sent;
							jsfiles = files.filter(function (file) {
								return file.endsWith('.js');
							});
							return _context2.abrupt('return', jsfiles[0]);

						case 5:
						case 'end':
							return _context2.stop();
					}
				}
			}, _callee2, _this);
		}))();
	},
	version: function version(id, dir, repo) {
		var _this2 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3() {
			var master, commits;
			return _regenerator2.default.wrap(function _callee3$(_context3) {
				while (1) {
					switch (_context3.prev = _context3.next) {
						case 0:
							_context3.next = 2;
							return repo.getBranchCommit('master');

						case 2:
							master = _context3.sent;
							_context3.next = 5;
							return new _bluebird2.default(function (resolve, reject) {
								var history = master.history();
								history.on('end', resolve);
								history.on('error', reject);
								history.start();
							});

						case 5:
							commits = _context3.sent;
							return _context3.abrupt('return', '1.' + (commits.length - 1) + '.0');

						case 7:
						case 'end':
							return _context3.stop();
					}
				}
			}, _callee3, _this2);
		}))();
	},
	name: function name(id, dir, repo) {
		var _this3 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee4() {
			var main, name, gist;
			return _regenerator2.default.wrap(function _callee4$(_context4) {
				while (1) {
					switch (_context4.prev = _context4.next) {
						case 0:
							_context4.next = 2;
							return infer.main(id, dir, repo);

						case 2:
							main = _context4.sent;
							name = _path2.default.basename(main, '.js');
							_context4.next = 6;
							return getGist(id);

						case 6:
							gist = _context4.sent;
							return _context4.abrupt('return', '@' + gist.owner.login + '/' + name);

						case 8:
						case 'end':
							return _context4.stop();
					}
				}
			}, _callee4, _this3);
		}))();
	},
	author: function author(id, dir, repo) {
		var _this4 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee5() {
			var commit, author;
			return _regenerator2.default.wrap(function _callee5$(_context5) {
				while (1) {
					switch (_context5.prev = _context5.next) {
						case 0:
							_context5.next = 2;
							return repo.getBranchCommit('master');

						case 2:
							commit = _context5.sent;
							_context5.next = 5;
							return commit.author();

						case 5:
							author = _context5.sent;
							return _context5.abrupt('return', author.name() + ' <' + author.email() + '>');

						case 7:
						case 'end':
							return _context5.stop();
					}
				}
			}, _callee5, _this4);
		}))();
	},
	bin: function bin(id, dir, repo) {
		var _this5 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee6() {
			var main, src, firstLine;
			return _regenerator2.default.wrap(function _callee6$(_context6) {
				while (1) {
					switch (_context6.prev = _context6.next) {
						case 0:
							_context6.next = 2;
							return infer.main(id, dir, repo);

						case 2:
							main = _context6.sent;
							_context6.next = 5;
							return fs.readFileAsync(_path2.default.resolve(dir, main), 'utf8');

						case 5:
							src = _context6.sent;
							firstLine = src.split('\n')[0];

							if (!(firstLine === '#!/usr/bin/env node')) {
								_context6.next = 9;
								break;
							}

							return _context6.abrupt('return', main);

						case 9:
						case 'end':
							return _context6.stop();
					}
				}
			}, _callee6, _this5);
		}))();
	},
	dependencies: function dependencies(id, dir, repo) {
		var _this6 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee7() {
			var mainPath, src, packages;
			return _regenerator2.default.wrap(function _callee7$(_context7) {
				while (1) {
					switch (_context7.prev = _context7.next) {
						case 0:
							_context7.t0 = _path2.default;
							_context7.t1 = dir;
							_context7.next = 4;
							return infer.main(id, dir, repo);

						case 4:
							_context7.t2 = _context7.sent;
							mainPath = _context7.t0.resolve.call(_context7.t0, _context7.t1, _context7.t2);
							_context7.next = 8;
							return fs.readFileAsync(mainPath, 'utf8');

						case 8:
							src = _context7.sent;
							packages = (0, _detective2.default)(src);
							return _context7.abrupt('return', stars(packages.filter(function (p) {
								return p.indexOf('.') !== 0 && _builtinModules2.default.indexOf(p) === -1;
							}).map(actualPackageName)));

						case 11:
						case 'end':
							return _context7.stop();
					}
				}
			}, _callee7, _this6);
		}))();
	},
	repository: function repository(id, dir, repo) {
		return 'gist:' + id;
	},
	homepage: function homepage(id, dir, repo) {
		return 'https://gist.github.com/' + id;
	},
	devDependencies: function devDependencies() {
		return {
			'babel-cli': '^6.0.0',
			'babel-preset-es2015': '^6.0.0'
		};
	},
	babel: function babel() {
		return {
			presets: ['es2015']
		};
	},
	scripts: function scripts(id, dir, repo) {
		var _this7 = this;

		return (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee8() {
			var main, orig, compiled;
			return _regenerator2.default.wrap(function _callee8$(_context8) {
				while (1) {
					switch (_context8.prev = _context8.next) {
						case 0:
							_context8.next = 2;
							return infer.main(id, dir, repo);

						case 2:
							main = _context8.sent;
							orig = _path2.default.resolve(dir, '_' + main);
							compiled = _path2.default.resolve(dir, main);
							return _context8.abrupt('return', {
								prepublish: 'mv ' + compiled + ' ' + orig + ' ; babel ' + orig + ' -o ' + compiled
							});

						case 6:
						case 'end':
							return _context8.stop();
					}
				}
			}, _callee8, _this7);
		}))();
	}
};

var actualPackageName = function actualPackageName(req) {
	return req.split('/', req[0] === '@' ? 2 : 1).join('/');
};
var stars = function stars(deps) {
	return arraysToObj(deps, arrayN(deps.length, '*'));
}; //yolo
var arrayN = function arrayN(n, x) {
	return n <= 0 ? [] : [x].concat(arrayN(n - 1, x));
};
var arraysToObj = function arraysToObj(xs, ys) {
	return xs.reduce(function (o, x, i) {
		return o[x] = ys[i], o;
	}, {});
};

;

module.exports = function () {
	var ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee10(id, dir, repo) {
		var keys, values, base, extra;
		return _regenerator2.default.wrap(function _callee10$(_context10) {
			while (1) {
				switch (_context10.prev = _context10.next) {
					case 0:
						keys = (0, _keys2.default)(infer);
						_context10.next = 3;
						return _bluebird2.default.all(keys.map(function (k) {
							return infer[k](id, dir, repo);
						}));

					case 3:
						values = _context10.sent;
						base = arraysToObj(keys, values.filter(function (v) {
							return v;
						}));
						_context10.next = 7;
						return getExtraMetadata(id);

					case 7:
						extra = _context10.sent;
						return _context10.abrupt('return', (0, _lodash2.default)(base, extra));

					case 9:
					case 'end':
						return _context10.stop();
				}
			}
		}, _callee10, this);
	}));
	return function (_x3, _x4, _x5) {
		return ref.apply(this, arguments);
	};
}();
